#pragma once

#include <Base_Configurator.h>
#include <mysql-cppconn/mysql/jdbc.h>

namespace inaf::oasbo::Configurators {

/**
 * @brief A class that represents a MySQL configurator.
 * 
 * This class is responsible for reading and pushing configurations to a MySQL database.
 * It inherits from the BaseConfigurator class. Check Base_Configurator.h for more information.
 */

class MysqlConfigurator: public BaseConfigurator {
protected:
	sql::mysql::MySQL_Driver *driver = nullptr;
	sql::Connection *con = nullptr;

public:
	/**
	 * @brief Constructs a MysqlConfigurator object with the specified parameters.
	 * 
	 * @param ip The IP address of the MySQL server.
	 * @param port The port number of the MySQL server.
	 * @param username The username for connecting to the MySQL server.
	 * @param password The password for connecting to the MySQL server.
	 * @param dbname The name of the MySQL database.
	 */
	MysqlConfigurator(std::string ip, int port, std::string username,
			std::string password, std::string dbname);

	int readConfigFromSource() override;

	int readConfigFromSource(std::string target) override;

	int pushConfigToSource() override;

	int pushConfigToSource(std::string target) override;

	int insert(std::map<std::string, std::string>, std::string target) override;

	~MysqlConfigurator() {
		if (con != nullptr) {
			con->close();
			delete con;
		}
	}
};
}
